@@ -1,4 +1,4 @@
-# GNU Solfege - eartraining for GNOME
+# GNU Solfege - ear training for GNOME
 # Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
@@ -16,8 +16,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 MAJOR_VERSION = 2
-MINOR_VERSION = 0
-PATCH_LEVEL= 7
+MINOR_VERSION = 1
+PATCH_LEVEL= 3
 VERSION_STRING = '%s.%s.%s' % (MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL)
 if "yes" == "yes":
    WITH_GNOME = 1
@@ -26,5 +26,5 @@ else:
 WITH_GTKHTML = "yes" == 'yes'
 prefix = "/usr/local"
 sysconfdir = "${prefix}/etc"
-HAVE_LINUX_AWE_VOICE_H = "yes" != ""
+HAVE_LINUX_AWE_VOICE_H = "yes" == "yes"
 ENABLE_TUNER = "no" == "yes"
